@@ -23,6 +23,7 @@ from tornado.options import define, options
 
 # Project Imports
 import aegis.stdlib
+import aegis.database
 import aegis.model
 import aegis.build
 import config
@@ -166,10 +167,11 @@ class HydraHead(HydraThread):
                         if hydra_type['next_run_sql']:
                             singleton = hydra_queue.singleton()
                             if singleton:
-                                logging.error("%s card_assets already running" % self.name)
+                                logging.error("%s %s already running" % (self.name, hydra_type['hydra_type_name']))
                                 hydra_queue.finish()    # Not complete, since that affects status
                                 continue
-                        logging.warning("%s RUN HYDRA QUEUE: %s %s" % (self.name, hydra_queue['hydra_queue_id'], hydra_type['hydra_type_name']))
+                        if aegis.config.get('hydra_debug'):
+                            logging.warning("%s RUN HYDRA QUEUE: %s %s" % (self.name, hydra_queue['hydra_queue_id'], hydra_type['hydra_type_name']))
                         hydra_queue.incr_try_cnt()
                         hydra_queue.start()
                         result, work_cnt = work_fn(hydra_queue, hydra_type)
@@ -178,13 +180,13 @@ class HydraHead(HydraThread):
                         if result:
                             hydra_queue.complete()
                         else:
-                            logging.error("hydra_queue_id %s failed, will retry every 15m", hydra_queue['hydra_queue_id'])
+                            logging.error("%s hydra_queue_id %s failed, will retry every 15m", self.name, hydra_queue['hydra_queue_id'])
                             hydra_queue.incr_error_cnt(minutes=15)
                             hydra_queue.unclaim()
                             continue
                         aegis.stdlib.timer_stop(self.timer_obj, 'hydra_queue_run')
                         # Worker accounting
-                        logging.warning(self.log_line(hydra_type, work_cnt, self.timer_msg()))
+                        logging.info(self.log_line(hydra_type, work_cnt, self.timer_msg()))
                         self.processed_cnt += work_cnt
                     except Exception as ex:
                         logging.error("Exception when working on hydra_queue_id: %s", hydra_queue['hydra_queue_id'])
@@ -287,11 +289,9 @@ class HydraHead(HydraThread):
         # Delete any builds that are undeployed or deleted and older than a week.
         dead_builds = aegis.model.Build.scan_dead_builds()
         for dead_build in dead_builds:
-            self.logw(dead_build['build_id'], "DEAD BUILD - should clean it up")
             build.clean(dead_build)
         # Keep the 5 most recently deployed builds per environment. Delete the rest.
         envs = [env['env'] for env in aegis.model.Build.deployed_envs()]
-        self.logw(envs, "ENVS")
         for env in envs:
             stale_builds = aegis.model.Build.scan_stale_builds(env)
             for stale_build in stale_builds[5:]:
@@ -358,6 +358,8 @@ class Hydra(HydraThread):
                             hydra_queue['hydra_type_id'] = hydra_type['hydra_type_id']
                             hydra_queue['priority_ndx'] = hydra_type['priority_ndx']
                             hydra_queue['work_dttm'] = aegis.database.Literal("NOW()")
+                            if hydra_type.get('run_host'):
+                                hydra_queue['work_host'] = hydra_type['run_host']
                             hydra_queue_id = aegis.model.HydraQueue.insert_columns(**hydra_queue)
                             hydra_type.schedule_next()
                             _hydra_type = aegis.model.HydraType.get_id(hydra_type['hydra_type_id'])
@@ -372,16 +374,23 @@ class Hydra(HydraThread):
                             if past_items and len(past_items):
                                 #logging.error("HydraQueue has %s stuck items", len(past_items))
                                 for past_item in past_items:
-                                    logging.error("Running stuck hydra_queue_id: %s", past_item['hydra_queue_id'])
+                                    past_item_type = aegis.model.HydraType.get_id(past_item['hydra_type_id'])
+                                    logging.error("Running stuck hydra_queue_id: %s  hydra_type_name: %s", past_item['hydra_queue_id'], past_item_type['hydra_type_name'])
                                     past_item.run_now()
                             # Any hydra_type claimed since the next_run_dttm and over 5m old are stuck. Automatically unclaim them.
                             past_items = aegis.model.HydraType.past_items(minutes=self.stuck_minutes)
                             if past_items and len(past_items):
                                 #logging.error("HydraType has %s stuck items", len(past_items))
                                 for past_item in past_items:
-                                    logging.error("Unclaiming stuck hydra_type_id: %s", past_item['hydra_type_name'])
+                                    logging.error("Unclaiming stuck hydra_type_id: %s  hydra_type_name: %s", past_item['hydra_type_name'], past_item['hydra_type_name'])
                                     past_item.unclaim()
 
+                # Better handling of AdminShutdown, OperationalError, to capture structured and complete data to logs and alerts.
+                except (aegis.database.PgsqlAdminShutdown, aegis.database.PgsqlOperationalError, aegis.database.MysqlOperationalError, aegis.database.MysqlInterfaceError) as ex:
+                    aegis.stdlib.loge(ex, "Database is Down. Pause 3 seconds.")
+                    logging.exception(ex)
+                    self.exception_alert(ex)
+                    time.sleep(3)
                 except Exception as ex:
                     logging.exception("Batch had an inner loop failure.")
                     self.exception_alert(ex)
