@@ -281,11 +281,17 @@ class AegisHandler(tornado.web.RequestHandler):
         return ck
 
     def cookie_name(self, name):
-        if self.tmpl['env'] != 'prod':
+        if self.tmpl['env'] == 'prod':
+            return name
+        # Authentication for special -admin environment to use cookies from the main env
+        if self.tmpl['env'].endswith('-admin'):
+            name = "%s_%s" % (self.tmpl['env'].split('-')[0], name)
+        else:
             name = "%s_%s" % (self.tmpl['env'], name)
+        aegis.stdlib.logw(self.tmpl['env'], "ENV")
+        aegis.stdlib.logw(name, "COOKIE NAME")
         return name
 
-
     def cookie_set(self, name, value, cookie_duration=None):
         # Session cookie is set to None duration to implement a browser session cookie
         if not cookie_duration:
@@ -979,7 +985,13 @@ class AegisBuildForm(AegisWeb):
             return self.render_path("build_form.html", **self.tmpl)
         if not build['revision']:
             build['revision'] = 'HEAD'
+        aegis.stdlib.logw(aegis.config.get('env'), "RUNNING ENV")
         build['env'] = aegis.config.get('env')
+        if aegis.config.get('env').endswith('-admin'):
+            build['env'] = aegis.config.get('env').split('-')[0]
+        aegis.stdlib.logw(build['env'], "SET BUILD ENV FROM PROCESS ENV")
+        # XXX This should be env-admin
+
         # Create build row and add it to run on Hydra
         build_id = aegis.model.Build.insert_columns(**build)
         hydra_type = aegis.model.HydraType.get_name('build_build')
